@@ -3,7 +3,7 @@ from .constants import DESCRIPTION
 
 from disnake import ButtonStyle, Message, MessageInteraction, TextChannel
 from disnake.ui import View, Button, button
-from disnake.ext.commands import Context
+from disnake.ext.commands import Context, Bot
 
 newline = "\n"
 bot_statistics = """
