@@ -3,8 +3,13 @@ from ..constants import ERROR, THUMBS_UP
 
 from disnake import Message, MessageInteraction, ButtonStyle
 from disnake.ui import View, Button, button
-from disnake.ext.commands import Context, Bot, ExtensionNotFound, ExtensionAlreadyLoaded, ExtensionNotLoaded
-
+from disnake.ext.commands import (
+    Context,
+    Bot,
+    ExtensionNotFound,
+    ExtensionAlreadyLoaded,
+    ExtensionNotLoaded,
+)
 
 
 class Cogs(View):
@@ -31,12 +36,20 @@ class Cogs(View):
     @button(label="Load", style=ButtonStyle.green)
     async def load_button(self, button: Button, interaction: MessageInteraction):
         embed = EmbedFactory.static_embed(
-            self.ctx, "Manage cogs", path="cog/load", description="What is the file path of the cog you want to load?"
+            self.ctx,
+            "Manage cogs",
+            path="cog/load",
+            description="What is the file path of the cog you want to load?",
         )
         await self.bot_message.edit(embed=embed)
-        await interaction.response.send_message("What cog do you want to load?", ephemeral=True)
+        await interaction.response.send_message(
+            "What cog do you want to load?", ephemeral=True
+        )
 
         message: Message = await self.bot.wait_for("message", check=self.check)
+        if message.content == "q":
+            return await interaction.message.reply("Cancelled the current `wait_for`")
+
         fp = message.content.replace("/", ".")
 
         try:
@@ -49,7 +62,10 @@ class Cogs(View):
             return await self.bot_message.edit(embed=self.cog_already_loaded)
 
         embed = EmbedFactory.static_embed(
-            self.ctx, "Manage cogs", path="cog/load/success", description=f"Successfully loaded {fp}"
+            self.ctx,
+            "Manage cogs",
+            path="cog/load/success",
+            description=f"Successfully loaded {fp}",
         )
         await message.add_reaction(THUMBS_UP)
         await self.bot_message.edit(embed=embed)
@@ -57,12 +73,20 @@ class Cogs(View):
     @button(label="Unload", style=ButtonStyle.green)
     async def unload_button(self, button: Button, interaction: MessageInteraction):
         embed = EmbedFactory.static_embed(
-            self.ctx, "Manage cogs", path="cog/unload", description="What is the file path of the cog you want to unload?"
+            self.ctx,
+            "Manage cogs",
+            path="cog/unload",
+            description="What is the file path of the cog you want to unload?",
         )
         await self.bot_message.edit(embed=embed)
-        await interaction.response.send_message("What cog do you want to unload?", ephemeral=True)
+        await interaction.response.send_message(
+            "What cog do you want to unload?", ephemeral=True
+        )
 
         message: Message = await self.bot.wait_for("message", check=self.check)
+        if message.content == "q":
+            return await interaction.message.reply("Cancelled the current `wait_for`")
+
         fp = message.content.replace("/", ".")
 
         try:
@@ -75,21 +99,31 @@ class Cogs(View):
             return await self.bot_message.edit(embed=self.cog_not_loaded)
 
         embed = EmbedFactory.static_embed(
-            self.ctx, "Manage cogs", path="cog/unload/success", description=f"Successfully unloaded {fp}"
+            self.ctx,
+            "Manage cogs",
+            path="cog/unload/success",
+            description=f"Successfully unloaded {fp}",
         )
         await message.add_reaction(THUMBS_UP)
         await self.bot_message.edit(embed=embed)
 
-
     @button(label="Reload", style=ButtonStyle.green)
     async def reload_button(self, button: Button, interaction: MessageInteraction):
         embed = EmbedFactory.static_embed(
-            self.ctx, "Manage cogs", path="cog/reload", description="What is the file path of the cog you want to reload?"
+            self.ctx,
+            "Manage cogs",
+            path="cog/reload",
+            description="What is the file path of the cog you want to reload?",
         )
         await self.bot_message.edit(embed=embed)
-        await interaction.response.send_message("What cog do you want to reload?", ephemeral=True)
+        await interaction.response.send_message(
+            "What cog do you want to reload?", ephemeral=True
+        )
 
         message: Message = await self.bot.wait_for("message", check=self.check)
+        if message.content == "q":
+            return await interaction.message.reply("Cancelled the current `wait_for`")
+
         fp = message.content.replace("/", ".")
 
         try:
@@ -102,7 +136,10 @@ class Cogs(View):
             return await self.bot_message.edit(embed=self.cog_not_loaded)
 
         embed = EmbedFactory.static_embed(
-            self.ctx, "Manage cogs", path="cog/reload/success", description=f"Successfully reloaded {fp}"
+            self.ctx,
+            "Manage cogs",
+            path="cog/reload/success",
+            description=f"Successfully reloaded {fp}",
         )
         await message.add_reaction(THUMBS_UP)
-        await self.bot_message.edit(embed=embed)
\ No newline at end of file
+        await self.bot_message.edit(embed=embed)
