@@ -1,8 +1,15 @@
 from typing import List
-from ..utils import EMBED_COLOR, MainMenu, get_bot_message
-from ..constants import THUMBS_UP
+from ..utils import MainMenu, get_bot_message
+from ..constants import THUMBS_UP, EMBED_COLOR
 
-from disnake import HTTPException, TextChannel, Message, MessageInteraction, ButtonStyle, Embed
+from disnake import (
+    HTTPException,
+    TextChannel,
+    Message,
+    MessageInteraction,
+    ButtonStyle,
+    Embed,
+)
 from disnake.ui import View, Button, button
 from disnake.ext.commands import Context, Bot
 
@@ -50,9 +57,7 @@ class Channel(View):
         i = 29
         while True:
             try:
-                await self.bot_message.edit(
-                    embed=self.embed
-                )
+                await self.bot_message.edit(embed=self.embed)
                 return
             except HTTPException:
                 i -= 2
@@ -66,45 +71,37 @@ class Channel(View):
         self.messages.pop(0)
         self.messages.append(f"[{message.id}] {message.author.name}: {message.content}")
         self.embed.description = "```yaml\n" + "\n".join(self.messages) + "```"
-        
+
         while True:
             try:
-                await self.bot_message.edit(
-                    embed=self.embed
-                )
+                await self.bot_message.edit(embed=self.embed)
                 return
             except HTTPException:
                 self.messages.pop(0)
                 self.embed.description = "```yaml\n" + "\n".join(self.messages) + "```"
-            
+
     async def message_deleted(self, message: Message) -> None:
-        if not any(
-            str(message.id) in msg for msg in self.messages
-        ):
+        if not any(str(message.id) in msg for msg in self.messages):
             return
         self.messages.remove(f"[{message.id}] {message.author.name}: {message.content}")
         self.embed.description = "```yaml\n" + "\n".join(self.messages) + "```"
-        await self.bot_message.edit(
-            embed=self.embed
-        )
+        await self.bot_message.edit(embed=self.embed)
 
     async def message_edited(self, before: Message, after: Message) -> None:
-        if not any(
-            str(before.id) in msg for msg in self.messages
-        ):
+        if not any(str(before.id) in msg for msg in self.messages):
             return
-        self.messages[self.messages.index(f"[{before.id}] {before.author.name}: {before.content}")] = f"[{after.id}] {after.author.name}: {after.content}"
+        self.messages[
+            self.messages.index(f"[{before.id}] {before.author.name}: {before.content}")
+        ] = f"[{after.id}] {after.author.name}: {after.content}"
         self.embed.description = "```yaml\n" + "\n".join(self.messages) + "```"
-        await self.bot_message.edit(
-            embed=self.embed
-        )
+        await self.bot_message.edit(embed=self.embed)
 
     async def specific_channel_message(self, message: Message) -> None:
         if message.channel.id != self.channel.id:
             return
         if message.author.bot and message.author != self.bot.user:
             return
-        await self.update_embed(message)   
+        await self.update_embed(message)
 
     async def specific_channel_message_delete(self, message: Message) -> None:
         if message.channel.id != self.channel.id:
@@ -113,7 +110,9 @@ class Channel(View):
             return
         await self.message_deleted(message)
 
-    async def specific_channel_message_edited(self, before: Message, after: Message) -> None:
+    async def specific_channel_message_edited(
+        self, before: Message, after: Message
+    ) -> None:
         if before.channel.id != self.channel.id:
             return
         if before.author.bot and before.author != self.bot.user:
@@ -125,10 +124,16 @@ class Channel(View):
         self, button: Button, interaction: MessageInteraction
     ):
         if not self.channel.permissions_for(self.ctx.me).send_messages:
-            return await interaction.response.send_message("I do not have permissions to send messages", ephemeral=True)
+            return await interaction.response.send_message(
+                "I do not have permissions to send messages", ephemeral=True
+            )
 
-        await interaction.response.send_message("What would you like to say?", ephemeral=True)
+        await interaction.response.send_message(
+            "What would you like to say?", ephemeral=True
+        )
         message: Message = await self.bot.wait_for("message", check=self.check)
+        if message.content == "q":
+            return await interaction.message.reply("Cancelled the current `wait_for`")
 
         await self.channel.send(message.content)
 
@@ -137,15 +142,21 @@ class Channel(View):
         self, button: Button, interaction: MessageInteraction
     ):
         if not self.channel.permissions_for(self.ctx.me).manage_messages:
-            return await interaction.response.send_message("I do not have permissions to delete messages", ephemeral=True)
+            return await interaction.response.send_message(
+                "I do not have permissions to delete messages", ephemeral=True
+            )
 
         await interaction.response.send_message("What message id?", ephemeral=True)
         message: Message = await self.bot.wait_for("message", check=self.check)
+        if message.content == "q":
+            return await interaction.message.reply("Cancelled the current `wait_for`")
 
         try:
             deleteable = await self.channel.fetch_message(int(message.content))
         except HTTPException:
-            return await interaction.send(f"Could not find message with id {message.content}")
-            
+            return await interaction.send(
+                f"Could not find message with id {message.content}"
+            )
+
         await deleteable.delete()
-        await message.add_reaction(THUMBS_UP)
\ No newline at end of file
+        await message.add_reaction(THUMBS_UP)
